Again, as you see this page has run the macro for this page. If you try to refresh you will see that the counter won't increase. That's because the macro is called only once, but different pages don't share the same expanded macro when you use xhtml templates with xmlfile. Currently loaders.stan, loaders.htmlfile, loaders.htmlstr, loaders.xmlstr do not allow this 'macro sharing' functionality because of the way they handle template cache. This will be fixed in the future.

Back